import valideer
from valideer import Validator, ValidationError
import timestring

class ScriptElement(Validator):
    def __init__(self, *types):
        self.types = set(types)

    def validate(self, element, adapt=True):
        # convert the Script object to a string representation
        return element
        if self.types & element.types:
            return element
        else:
            raise ValidationError("Invalid element provided, expected %s but got %s" % (str(self.types).replace('set([', 'any(['), repr(element)))

class Timestring(Validator):
    def validate(self, element, adapt=True):
        return element
        try:
            timestring.Date(str(element))
            return element
        except:
            raise ValidationError("Invalid date provided for %s" % (self.name, repr(element)))

valideer.register("twitter_handler", ScriptElement("twitter_handler"))
valideer.register("media.hbs", ScriptElement("media.hbs"))
valideer.register("string", ScriptElement("string"))
valideer.register("number", ScriptElement("number"))
valideer.register("user", ScriptElement("user"))
valideer.register("timestring", Timestring())
